pub struct MachinePrivateKey(/* private fields */);Expand description
The X25519 private key of a unique piece of hardware running one or more Tailscale nodes.
Implementations
Sourceimpl MachinePrivateKey
impl MachinePrivateKey
Sourcepub const KEY_LEN_BYTES: usize = 32
pub const KEY_LEN_BYTES: usize = 32
The length of this key type, in bytes.
Sourcepub const KEY_LEN_HEX_STR: usize
pub const KEY_LEN_HEX_STR: usize
The length of a hexidecimal string representation of this key, excluding the prefix and colon.
Sourcepub const KEY_LEN_FULL_STR: usize
pub const KEY_LEN_FULL_STR: usize
The length of a hexidecimal string representation of this key, including the prefix and colon.
Sourcepub const KEY_PREFIX: &'static str = "privkey"
pub const KEY_PREFIX: &'static str = "privkey"
The prefix placed in front of string representations of this key type, such as “$key_prefix:abcd…”
Sourceimpl MachinePrivateKey
impl MachinePrivateKey
Sourcepub fn public_key(self) -> MachinePublicKey
pub fn public_key(self) -> MachinePublicKey
Calculate the corresponding public key for this private key.